@@ -9,13 +9,13 @@
 
 __docformat__ = 'numpy'
 __author__ = "Jonas Van Der Donckt, Jeroen Van Der Donckt, Emiel Deprost"
-__version__ = '0.1.1.8'
+__version__ = '0.1.1.9'
 __pdoc__ = {
     # do not show tue utils module
     'tsflex.utils': False,
-    # show the seriesprocessor & numpyfuncwrapper their call method
+    # show the seriesprocessor & funcwrapper their call method
     'SeriesProcessor.__call__': True,
-    'NumpyFuncWrapper.__call__': True,
+    'FuncWrapper.__call__': True,
 }
 
 __all__ = ["__version__", "__pdoc__"]
