@@ -5,8 +5,11 @@ __author__ = "Jeroen Van Der Donckt, Jonas Van Der Donckt"
 import itertools
 from typing import Any, Dict, Iterable, Iterator, List, Union, Tuple
 
+import numpy as np
 import pandas as pd
 
+SUPPORTED_STROLL_TYPES = [np.array, pd.Series]
+
 
 def series_dict_to_df(series_dict: Dict[str, pd.Series]) -> pd.DataFrame:
     """Convert the `series_dict` into a pandas DataFrame with an outer merge.
